## Humps

Underscore-to-camelCase converter (and vice versa) for strings and dictionary keys in Python.

When converting dictionary keys, it will recusively iterate over each key/value pairs, converting any nested dictionaries (or lists of nested dictionaries) along the way.
This feature is maintaining idiomatic data formatting when interacting with data seralized from/to different languages.

Takes inspiration from [Humps](https://github.com/domchristie/humps).
